{ ============================================================================== }
{ Copyright(c) 1996-2009 InstallAware Software Corporation. All rights reserved. }
{ This source code provided for demonstrative use only. All rights reserved.     }
{ ============================================================================== }

library mIDEPlug;

uses
  SysUtils,
  Controls,
  Classes,
  Windows,
  uIDE in 'uIDE.pas' {IDEPlugIn},
  uSharedDLL in 'uSharedDLL.pas';

{
  This function is called during Compile Time
  MSIHandle: Handle to MSI file being built
  State: State of plug-in controls, as provided to the IDE previously
  BuildPath: Output folder for build that plug-in should use
  Build: Whether any plug-in and/or support files should actually be copied
  Fetch: Whether plug-in will require any files in addition to the runtime DLL
  Return: Set to TRUE if compile succeeds, FALSE if it fails
  See help for details
}
function CompileTimeBuild(MSIHandle: THandle; State, BuildPath: PChar; Build: Boolean;
  var Fetch: Boolean): Boolean; stdcall; export;
var
  l: TStringList;
  Option1: Boolean;
  Variable: String;
begin
  Result := True; // compile time build successful
  l := TStringList.Create;
  l.CommaText := State;
  Option1 := l[0] = 'TRUE';
  Fetch := not Option1; // assume option 2 requires some files to be added to build media
  Variable := l[1];
  l.Free;
  if Build then
  begin
    // add files to build media, if necessary
    if not Option1 then
      CopyFile(PChar(ModuleFolder + '2copy\example.txt'),
        PChar(BuildPath + 'example.txt'), false);
    // copy runtime DLL
    CopyFile(PChar(ModuleFolder + 'mEXEPlug.dll'),
      PChar(BuildPath + 'mEXEPlug.dll'), false);
  end;
end;

{
  This function is called during Design Time
  Window: Handle to parent window
  State: State of plug-in controls, as provided to the IDE previously
  NewState: New state of plug-in controls, as edited by user
  See help for details
}
function DesignTimeEdit(Window: THandle; State: PChar; NewState: PChar): Integer; stdcall; export;
var
  l: TStringList; // string list to hold state of user selections
begin
  if NewState = nil then
  begin
    { this call is to display the user interface }
    IDEPlugIn := TIDEPlugIn.Create(nil);
    l := TStringList.Create;
    if State = nil then
    // default values enter here
    begin
      l.Add('FALSE');
      l.Add('');
    end
    else
    l.CommaText := State;
    with IDEPlugIn do
    begin
      // initialize values of variables
      Option1.Checked := l[0] = 'TRUE';
      Option2.Checked := not Option1.Checked;
      Variable.Text := l[1];
      // display dialog
      if ShowModal = mrOk then
      begin
        // save values of variables
        if Option1.Checked then l[0] := 'TRUE'
          else l[0] := 'FALSE';
        l[1] := Variable.Text;
        // strNewState holds state of user selections passed back to IDE
        strNewState := l.CommaText;
        Result := Length(strNewState);
      end
      else
        Result := -1;
    end;
    l.Free;
    IDEPlugIn.Free;
  end
  else
  begin
    { this call is to obtain user selection state }
    StrCopy(NewState, PChar(strNewState));
    Result := 0;
  end;
end;

{
  This function is called during Design Time
  State: State of plug-in controls, as provided to the IDE previously
  Text: Plug-in state represented textually in the IDE script view
  See help for details
}
function DesignTimeText(State, Text: PChar): Integer; stdcall; export;
var
  l: TStringList;
begin
  if Text = nil then
  begin
    { this call is to get length of the user readable text }
    l := TStringList.Create;
    l.CommaText := State;
    strNewState := ': ';
    if l[0] = 'TRUE' then
      strNewState := strNewState + 'Do something'
    else
      strNewState := strNewState + 'Do something else';
    if l[1] <> '' then
      strNewState := strNewState + ' (get result into variable ' + l[1] + ')';
    l.Free;
    Result := Length(strNewState);
  end
  else
  begin
    { this call is to obtain the actual user readable text }
    StrCopy(Text, PChar(strNewState));
    Result := 0;
  end;
end;

{
  This function is called during Design Time
  Window: Handle to parent window
  See help for details
}
procedure AboutPlugIn(Window: THandle); stdcall; export
begin
  MessageBox(Window, 'InstallAware Template Delphi Plug-In', 'About Plug-In',
    mb_Ok + mb_IconInformation);
end;

exports
  CompileTimeBuild,
  DesignTimeEdit,
  DesignTimeText,
  AboutPlugIn;

begin
  GetMem(p, 1024);
  GetModuleFileName(GetModuleHandle('mIDEPlug.dll'), p, 1024);
  ModuleFile := p;
  ModuleFolder := ExtractFilePath(p);
  FreeMem(p);
end.
